@@ -1,6 +1,15 @@
 #ifndef UTIL_H_INCLUDED
 #define UTIL_H_INCLUDED
 
+#include <ft2build.h>
+#include FT_FREETYPE_H
+#include FT_OUTLINE_H
+
+/* Freetype 2.6 introduces a macro TYPEOF that conflicts with R */
+#ifdef TYPEOF
+#undef TYPEOF
+#endif
+
 #include <R.h>
 #include <Rdefines.h>
 #include <Rinternals.h>
@@ -11,10 +20,6 @@
 #include <R_ext/GraphicsEngine.h>
 #include <R_ext/GraphicsDevice.h>
 
-#include <ft2build.h>
-#include FT_FREETYPE_H
-#include FT_OUTLINE_H
-
 
 /* Get the .pkg.env variable (an environment) defined in the package */
 /* The sysfonts and showtext packages are using this way to store variables */
